@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 ''' Single subject analysis script for SPM / FIAC '''
@@ -99,7 +99,7 @@ def coregister(data_def):
 
 
 def segnorm(data_def):
-    def_tpms = np.zeros((3,1), dtype=np.object)
+    def_tpms = np.zeros((3,1), dtype=object)
     spm_path = spm_info.spm_path
     def_tpms[0] = pjoin(spm_path, 'tpm', 'grey.nii'),
     def_tpms[1] = pjoin(spm_path, 'tpm', 'white.nii'),
