@@ -1,5 +1,7 @@
 # emacs: -*- coding: utf-8; mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set fileencoding=utf-8 ft=python sts=4 ts=4 sw=4 et:
+from __future__ import absolute_import
+
 import os
 
 from .info import (LONG_DESCRIPTION as __doc__,
@@ -7,27 +9,9 @@ from .info import (LONG_DESCRIPTION as __doc__,
                    STATUS as __status__,
                    __version__)
 
-# We require numpy 1.2 for our test suite.  If Tester fails to import,
-# check the version of numpy the user has and inform them they need to
-# upgrade.
-try:
-    from nipy.testing import Tester
-    test = Tester().test
-    bench = Tester().bench
-except ImportError:
-    # If the user has an older version of numpy which does not have
-    # the nose test framework, fail gracefully and prompt them to
-    # upgrade.
-    import numpy as np
-    npver = np.__version__.split('.')
-    npver = '.'.join((npver[0], npver[1]))
-    npver = float(npver)
-    if npver < 1.2:
-        raise ImportError('Nipy requires numpy version 1.2 or greater. '
-                          '\n    You have numpy version %s installed.'
-                          '\n    Please upgrade numpy:  '
-                          'http://www.scipy.org/NumPy' 
-                          % np.__version__)
+from nipy.testing import Tester
+test = Tester().test
+bench = Tester().bench
 
 
 def _test_local_install():
@@ -61,5 +45,3 @@ try:
     del Tester
 except:
     pass
-
-
