@@ -7,6 +7,8 @@ of the mixture distribution using an EM algorithm.
 
 Author: Bertrand Thirion and Merlin Keller 2005-2008
 """
+from __future__ import print_function
+from __future__ import absolute_import
 
 import numpy as np
 import scipy.stats as st
@@ -37,7 +39,7 @@ def _psi_solve(y, eps=0.00001):
     """ Solve psi(c)-log(c)=y by dichotomy
     """
     if y > 0:
-        print "y", y
+        print("y", y)
         raise ValueError("y>0, the problem cannot be solved")
     u = 1.
     if y > sp.psi(u) - np.log(u):
@@ -135,7 +137,7 @@ class Gamma(object):
         self.scale = scale
 
     def parameters(self):
-        print "shape: ", self.shape, "scale: ", self.scale
+        print("shape: ", self.shape, "scale: ", self.scale)
 
     def check(self, x):
         if (x.min() < 0):
@@ -185,9 +187,9 @@ class GGM(object):
     def parameters(self):
         """ print the paramteres of self
         """
-        print "Gaussian: mean: ", self.mean, "variance: ", self.var
-        print "Gamma: shape: ", self.shape, "scale: ", self.scale
-        print "Mixture gamma: ", self.mixt, "Gaussian: ", 1 - self.mixt
+        print("Gaussian: mean: ", self.mean, "variance: ", self.var)
+        print("Gamma: shape: ", self.shape, "scale: ", self.scale)
+        print("Mixture gamma: ", self.mixt, "Gaussian: ", 1 - self.mixt)
 
     def Mstep(self, x, z):
         """
@@ -271,7 +273,7 @@ class GGM(object):
             self.Mstep(x, z)
             z, L = self.Estep(x)
             if verbose:
-                print i, L
+                print(i, L)
             if (L < L0 + delta):
                 break
             L0 = L
@@ -376,14 +378,13 @@ class GGGM(object):
     def parameters(self):
         """ Print the parameters
         """
-        print "Negative Gamma: shape: ", self.shape_n,\
-        "scale: ", self.scale_n
-        print "Gaussian: mean: ", self.mean, "variance: ", self.var
-        print "Poitive Gamma: shape: ", self.shape_p, "scale: ",\
-        self.scale_p
+        print("Negative Gamma: shape: ", self.shape_n,
+              "scale: ", self.scale_n)
+        print("Gaussian: mean: ", self.mean, "variance: ", self.var)
+        print("Poitive Gamma: shape: ", self.shape_p, "scale: ", self.scale_p)
         mixt = self.mixt
-        print "Mixture neg. gamma: ", mixt[0], "Gaussian: ", mixt[1],\
-        "pos. gamma: ", mixt[2]
+        print("Mixture neg. gamma: ", mixt[0], "Gaussian: ", mixt[1],
+              "pos. gamma: ", mixt[2])
 
     def init(self, x, mixt=None):
         """
@@ -396,7 +397,7 @@ class GGGM(object):
         mixt : None or array of shape(3), optional
            prior mixing proportions. If None, the classes have equal weight
         """
-        if mixt != None:
+        if mixt is not None:
             if np.size(mixt) == 3:
                 self.mixt = np.ravel(mixt)
             else:
@@ -578,7 +579,7 @@ class GGGM(object):
 
             z, L = self.Estep(x)
             if verbose:
-                print i, L
+                print(i, L)
             if (L < L0 + delta):
                 break
             L0 = L
@@ -640,10 +641,12 @@ class GGGM(object):
         mpaxes: matplotlib axes, optional
             axes handle used for the plot if None, new axes are created.
         """
+        import matplotlib.pylab as mp
+
         step = 3.5 * np.std(x) / np.exp(np.log(np.size(x)) / 3)
         bins = max(10, int((x.max() - x.min()) / step))
         h, c = np.histogram(x, bins)
-        h = h.astype('d') / np.size(x)
+        h = h.astype(np.float) / np.size(x)
         dc = c[1] - c[0]
 
         ng = self.mixt[0] * _gam_dens(self.shape_n, self.scale_n, - c)
@@ -651,12 +654,12 @@ class GGGM(object):
         pg = self.mixt[2] * _gam_dens(self.shape_p, self.scale_p, c)
         z = y + pg + ng
 
-        import matplotlib.pylab as mp
-        if mpaxes == None:
+        if mpaxes is None:
             mp.figure()
             ax = mp.subplot(1, 1, 1)
         else:
             ax = mpaxes
+
         ax.plot(0.5 * (c[1:] + c[:-1]), h / dc, linewidth=2, label='data')
         ax.plot(c, ng, 'c', linewidth=2, label='negative gamma component')
         ax.plot(c, y, 'r', linewidth=2, label='Gaussian component')
