@@ -8,6 +8,8 @@ computationally and memory efficient.
 
 Author : Bertrand Thirion, 2006-2009
 """
+from __future__ import print_function
+from __future__ import absolute_import
 
 import numpy as np
 from scipy.linalg import eigvalsh
@@ -138,7 +140,7 @@ def best_fitting_GMM(x, krange, prec_type='full', niter=100, delta=1.e-4,
             bestbic = bic
             bgmm = gmmk
         if verbose:
-            print 'k', k, 'bic', bic
+            print('k', k, 'bic', bic)
     return bgmm
 
 
@@ -195,16 +197,16 @@ def plot2D(x, my_gmm, z=None, with_dots=True, log_scale=False, mpaxes=None,
     L = my_gmm.mixture_likelihood(grid)
     if verbose:
         intl = L.sum() * (xs - xm) * (ys - ym) / 2500
-        print 'integral of the density on the domain ', intl
+        print('integral of the density on the domain ', intl)
 
-    if mpaxes == None:
+    if mpaxes is None:
         plt.figure()
         ax = plt.subplot(1, 1, 1)
     else:
         ax = mpaxes
 
     gdx = gd1.n_bins[0]
-    Pdens = np.reshape(L, (gdx, np.size(L) / gdx))
+    Pdens = np.reshape(L, (gdx, -1))
     extent = [xm, xs, ym, ys]
     if log_scale:
         plt.imshow(np.log(Pdens.T), alpha=2.0, origin='lower',
@@ -213,11 +215,11 @@ def plot2D(x, my_gmm, z=None, with_dots=True, log_scale=False, mpaxes=None,
         plt.imshow(Pdens.T, alpha=2.0, origin='lower', extent=extent)
 
     if with_dots:
-        if z == None:
+        if z is None:
             plt.plot(x[:, 0], x[:, 1], 'o')
         else:
-            hsv = plt.cm.hsv(range(256))
-            col = hsv[range(0, 256, 256 // int(z.max() + 1))]
+            hsv = plt.cm.hsv(list(range(256)))
+            col = hsv[::(256 // int(z.max() + 1))]
             for k in range(z.max() + 1):
                 plt.plot(x[z == k, 0], x[z == k, 1], 'o', color=col[k])
 
@@ -275,17 +277,17 @@ class GMM(object):
         self.precisions = precisions
         self.weights = weights
 
-        if self.means == None:
+        if self.means is None:
             self.means = np.zeros((self.k, self.dim))
 
-        if self.precisions == None:
+        if self.precisions is None:
             if prec_type == 'full':
                 prec = np.reshape(np.eye(self.dim), (1, self.dim, self.dim))
                 self.precisions = np.repeat(prec, self.k, 0)
             else:
                 self.precisions = np.ones((self.k, self.dim))
 
-        if self.weights == None:
+        if self.weights is None:
             self.weights = np.ones(self.k) * 1.0 / self.k
 
     def plugin(self, means, precisions, weights):
@@ -702,7 +704,7 @@ class GMM(object):
         z: array of shape(n_samples): the resulting MAP labelling
            of the rows of x
         """
-        if like == None:
+        if like is None:
             like = self.likelihood(x)
         z = np.argmax(like, 1)
         return z
@@ -734,13 +736,13 @@ class GMM(object):
             av_ll = np.mean(np.log(np.maximum(np.sum(l, 1), tiny)))
             if av_ll < av_ll_old + delta:
                 if verbose:
-                    print 'iteration:', i, 'log-likelihood:', av_ll,\
-                          'old value:', av_ll_old
+                    print('iteration:', i, 'log-likelihood:', av_ll,
+                          'old value:', av_ll_old)
                 break
             else:
                 av_ll_old = av_ll
             if verbose:
-                print i, av_ll, self.bic(l)
+                print(i, av_ll, self.bic(l))
             self._Mstep(x, l)
 
         return self.bic(l)
@@ -835,7 +837,7 @@ class GMM(object):
         c += offset / 2
         grid = gd.make_grid()
 
-        if mpaxes == None:
+        if mpaxes is None:
             plt.figure()
             ax = plt.axes()
         else:
