@@ -1,9 +1,9 @@
-#!/usr/bin/env python
+from __future__ import absolute_import
 
 # to run only the simple tests:
 # python testClustering.py Test_Clustering
 
-from ..clustering import kmeans
+from ..utils import kmeans
 import nose
 import numpy as np
 import numpy.random as nr
