@@ -12,9 +12,13 @@ WeightedGraph and feature data.
 
 Author:Bertrand Thirion, 2006--2011
 """
+from __future__ import print_function
+from __future__ import absolute_import
+
+from warnings import warn
 import numpy as np
 
-from .graph import WeightedGraph
+from .graph import WeightedGraph, Graph
 
 NEGINF = -np.inf
 
@@ -102,7 +106,7 @@ class Field(WeightedGraph):
             self.edges = edges
             self.weights = weights
         self.field = []
-        if field == None:
+        if field is None:
             pass
         else:
             if np.size(field) == self.V:
@@ -148,18 +152,20 @@ class Field(WeightedGraph):
         self.dilation(nbiter)
 
     def dilation(self, nbiter=1, fast=True):
-        """
-        Morphological dimlation of the field data. self.field is changed
+        """Morphological dilation of the field data, changed in place
 
         Parameters
         ----------
         nbiter: int, optional, the number of iterations required
 
-        fixme
+        Notes
         -----
-        cython
+        When data dtype is not float64, a slow version of the code is used
         """
         nbiter = int(nbiter)
+        if self.field.dtype != np.float64:
+            warn('data type is not float64; a slower version is used')
+            fast = False
         if fast:
             from ._graph import dilation
             if self.E > 0:
@@ -177,16 +183,17 @@ class Field(WeightedGraph):
                 self.field = np.array([self.field[row].max(0) for row in rows])
 
     def highest_neighbor(self, refdim=0):
-        """ Computes the neighbor with highest field value along refdim
+        """Computes the neighbor with highest field value along refdim
 
         Parameters
         ----------
-        refdim: int optiontal, the dimension to consider
+        refdim: int, optional,
+                the dimension of the field under consideration
 
         Returns
         -------
-        hneighb: array of shape(self.V), index of the neighbor with highest
-                 value
+        hneighb: array of shape(self.V), 
+                 index of the neighbor with highest value
         """
         from scipy.sparse import dia_matrix
         refdim = int(refdim)
@@ -263,7 +270,7 @@ class Field(WeightedGraph):
         # create a subfield(thresholding)
         sf = self.subfield(self.field.T[refdim] >= th)
         initial_field = sf.field.T[refdim]
-        sf.field = initial_field.copy()
+        sf.field = initial_field.astype(np.float64)
 
         # compute the depth in the subgraph
         ldepth = sf.V * np.ones(sf.V, np.int)
@@ -315,7 +322,6 @@ class Field(WeightedGraph):
               labelling of the vertices according to their bassin
         """
         import numpy.ma as ma
-        from graph import Graph
 
         if (np.size(self.field) == 0):
             raise ValueError('No field has been defined so far')
@@ -429,9 +435,9 @@ class Field(WeightedGraph):
         -------
         label: The resulting labelling of the data
 
-        Fixme
+        Notes
         -----
-        deal with graphs with several ccs
+        FIXME: deal with graphs with several ccs
         """
         if np.size(self.field) == 0:
             raise ValueError('No field has been defined so far')
@@ -473,11 +479,11 @@ class Field(WeightedGraph):
         if np.size(self.field) == 0:
             raise ValueError('No field has been defined so far')
 
-        if (seeds == None) and (label == None):
+        if (seeds is None) and (label is None):
             raise ValueError('No initialization has been provided')
         k = np.size(seeds)
         inertia_old = NEGINF
-        if seeds == None:
+        if seeds is None:
             k = label.max() + 1
             if np.size(np.unique(label)) != k:
                 raise ValueError('missing values, cannot proceed')
@@ -505,7 +511,7 @@ class Field(WeightedGraph):
                 seeds[j] = lj[tj]
                 inertia += np.sum((cent - self.field[lj]) ** 2)
             if verbose:
-                print i, inertia
+                print(i, inertia)
             if np.absolute(inertia_old - inertia) < eps:
                 break
             inertia_old = inertia
@@ -562,7 +568,7 @@ class Field(WeightedGraph):
         sum(valid) == 0 then None is returned
         """
         G = self.subgraph(valid)
-        if G == None:
+        if G is None:
             return None
         field = self.field[valid]
         if len(G.edges) == 0:
