@@ -20,12 +20,14 @@ parameters::
     new_transformed_pts = obj.apply(pts)
 
 """
+from __future__ import absolute_import
 
 import numpy as np
 import numpy.linalg as npl
 
+from nibabel.affines import apply_affine
+
 from ..chain_transform import ChainTransform
-from ...utils.affines import apply_affine
 from ..affine import Affine
 
 from numpy.testing import (assert_array_almost_equal,
