@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 
@@ -8,12 +9,14 @@ def configuration(parent_package='', top_path=None):
 
     config.add_subpackage('tests')
     config.add_subpackage('registration')
+    config.add_subpackage('slicetiming')
     config.add_subpackage('segmentation')
     config.add_subpackage('statistics')
     config.add_subpackage('diagnostics')
     config.add_subpackage('clustering')
     config.add_subpackage('utils')
     config.add_subpackage('graph')
+    config.add_subpackage('group')
 
     return config
 
