@@ -3,13 +3,14 @@
 """
 Test functions for models.GLM
 """
+from __future__ import absolute_import
 
 import numpy as np
 
 from .. import family
 from ..glm import Model as GLM
 
-from nose.tools import assert_equal
+from nose.tools import assert_equal, assert_true, assert_false
 
 VARS = {}
 
@@ -28,6 +29,16 @@ def test_Logistic():
     assert_equal(results.df_resid, 30)
 
 
+def test_cont():
+    # Test continue function works as expected
+    X = VARS['X']
+    Y = VARS['Y']
+    cmodel = GLM(design=X, family=family.Binomial())
+    cmodel.fit(Y)
+    assert_true(cmodel.cont(0))
+    assert_false(cmodel.cont(np.inf))
+
+
 def test_Logisticdegenerate():
     X = VARS['X'].copy()
     X[:,0] = X[:,1] + X[:,2]
