@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 import numpy as np
@@ -57,7 +58,7 @@ def res2pos1(res):
     new_axes = [None] * bps.ndim
     n_comps = res['basis_projections'].shape[axis]
     new_axes[axis] = slice(0,n_comps)
-    res['basis_projections'] = bps * signs[new_axes]
+    res['basis_projections'] = bps * signs[tuple(new_axes)]
     return res
 
 
