@@ -14,6 +14,9 @@ CoordinateMap at np.indices(shape).
 The class Grid is meant to take a CoordinateMap and an np.mgrid-like
 notation to create an ArrayCoordMap.
 """
+from __future__ import print_function
+from __future__ import absolute_import
+
 import numpy as np
 
 from .coordinate_map import CoordinateMap, AffineTransform, compose
@@ -21,6 +24,9 @@ from .coordinate_map import product as cmap_product
 from .coordinate_map import shifted_range_origin
 from .coordinate_system import CoordinateSystem
 
+# Legacy repr printing from numpy.
+from nipy.testing import legacy_printing as setup_module  # noqa
+
 
 class ArrayCoordMap(object):
     """ Class combining coordinate map and array shape
@@ -184,6 +190,7 @@ class ArrayCoordMap(object):
         return "ArrayCoordMap(\n  coordmap=" + \
             '\n  '.join(repr(self.coordmap).split('\n')) + ',\n  shape=%s' % repr(self.shape) + '\n)'
 
+
 def _slice(coordmap, shape, *slices):
     """
     Slice a 'voxel' CoordinateMap's function_domain with slices. A
@@ -261,7 +268,6 @@ def _slice(coordmap, shape, *slices):
     A = A.astype(function_domain.coord_dtype)
     slice_cmap = AffineTransform(function_domain, coordmap.function_domain, A)
     return ArrayCoordMap(compose(coordmap, slice_cmap), tuple(newshape))
-                   
 
 
 class Grid(object):
@@ -277,16 +283,16 @@ class Grid(object):
            [ 0. ,  0.2, -2. ],
            [ 0. ,  0. ,  1. ]])
 
-    >>> print points.coordmap.function_domain
+    >>> print(points.coordmap.function_domain)
     CoordinateSystem(coord_names=('i0', 'i1'), name='product', coord_dtype=float64)
-    >>> print points.coordmap.function_range
+    >>> print(points.coordmap.function_range)
     CoordinateSystem(coord_names=('x', 'y'), name='input', coord_dtype=float64)
 
     >>> points.shape
     (21, 31)
-    >>> print points.transposed_values.shape
+    >>> print(points.transposed_values.shape)
     (2, 21, 31)
-    >>> print points.values.shape
+    >>> print(points.values.shape)
     (651, 2)
     """
 
