@@ -1,4 +1,6 @@
 """ Useful neuroimaging coordinate map makers and utilities """
+from __future__ import print_function
+from __future__ import absolute_import
 
 import numpy as np
 
@@ -9,12 +11,17 @@ from ...fixes.nibabel import io_orientation
 from .coordinate_system import CoordSysMaker, is_coordsys, is_coordsys_maker
 from .coordinate_map import CoordMapMaker
 
+from ...externals.six import string_types
+
+# Legacy repr printing from numpy.
+from nipy.testing import legacy_printing as setup_module  # noqa
+
 
 class XYZSpace(object):
     """ Class contains logic for spaces with XYZ coordinate systems
 
     >>> sp = XYZSpace('hijo')
-    >>> print sp
+    >>> print(sp)
     hijo: [('x', 'hijo-x=L->R'), ('y', 'hijo-y=P->A'), ('z', 'hijo-z=I->S')]
     >>> csm = sp.to_coordsys_maker()
     >>> cs = csm(3)
@@ -289,7 +296,7 @@ def get_world_cs(world_id, ndim=3, extras='tuvw', spaces=None):
         return world_id
     if spaces is None:
         spaces = known_spaces
-    if isinstance(world_id, basestring):
+    if isinstance(world_id, string_types):
         space_names = [s.name for s in spaces]
         if world_id not in space_names:
             raise SpaceError('Unkown space "%s"; known spaces are %s'
