@@ -16,11 +16,18 @@ The above three generators return 2-tuples.
 * write_data: write the output of a generator to an ndarray
 * parcels: return binary array of the unique components of data
 """
+from __future__ import print_function
+from __future__ import absolute_import
 
 import numpy as np
 
+from nipy.utils import seq_prod
 
-def parcels(data, labels=None, exclude=[]):
+# Legacy repr printing from numpy.
+from nipy.testing import legacy_printing as setup_module  # noqa
+
+
+def parcels(data, labels=None, exclude=()):
     """ Return a generator for ``[data == label for label in labels]``
 
     If labels is None, labels = numpy.unique(data).  Each label in labels can be
@@ -28,43 +35,59 @@ def parcels(data, labels=None, exclude=[]):
 
         [numpy.equal(data, l) for l in label]
 
+    Parameters
+    ----------
+    data : image or array-like
+        Either an image (with ``get_data`` method returning ndarray) or an
+        array-like
+    labels : iterable, optional
+        A sequence of labels for which to return indices within `data`. The
+        elements in `labels` can themselves be lists, tuples, in which case the
+        indices returned are for all values in `data` matching any of the items
+        in the list, tuple.
+    exclude : iterable, optional
+        Values in `labels` for which you do not want to return a parcel.
+
+    Returns
+    -------
+    gen : generator
+        generator yielding a array of boolean indices into `data` for which ``data
+        == label``, for each element in `label`.
+
     Examples
     --------
     >>> for p in parcels([[1,1],[2,1]]):
-    ...     print p
+    ...     print(p)
     ...
     [[ True  True]
      [False  True]]
     [[False False]
      [ True False]]
     >>> for p in parcels([[1,1],[2,3]], labels=[2,3]):
-    ...     print p
+    ...     print(p)
     ...
     [[False False]
      [ True False]]
     [[False False]
      [False  True]]
     >>> for p in parcels([[1,1],[2,3]], labels=[(2,3),2]):
-    ...     print p
+    ...     print(p)
     ...
     [[False False]
      [ True  True]]
     [[False False]
      [ True False]]
     """
+    # Get image data or make array from array-like
     try:
         data = data.get_data()
     except AttributeError:
         data = np.asarray(data)
-
     if labels is None:
         labels = np.unique(data)
-    if exclude:
-        labels = set(labels)
-        for e in exclude:
-            if e in labels:
-                labels.remove(e)
     for label in labels:
+        if label in exclude:
+            continue
         if type(label) not in [type(()), type([])]:
             yield np.equal(data, label)
         else:
@@ -85,7 +108,7 @@ def data_generator(data, iterable=None):
     >>> b = np.asarray([[False,False],[True,False]])
 
     >>> for i, d in data_generator(np.asarray([[1,2],[3,4]]), [a,b]):
-    ...     print d
+    ...     print(d)
     ...
     [1 4]
     [3]
@@ -122,15 +145,22 @@ def write_data(output, iterable):
 def slice_generator(data, axis=0):
     """ Return generator for yielding slices along `axis`
 
+    Parameters
+    ----------
+    data : array-like
+    axis : int or list or tuple
+        If int, gives the axis.  If list or tuple, gives the combination of
+        axes over which to iterate.  First axis is fastest changing in output.
+
     Examples
     --------
     >>> for i,d in slice_generator([[1,2],[3,4]]):
-    ...     print i, d
+    ...     print(i, d)
     ...
     (0,) [1 2]
     (1,) [3 4]
     >>> for i,d in slice_generator([[1,2],[3,4]], axis=1):
-    ...     print i, d
+    ...     print(i, d)
     ...
     (slice(None, None, None), 0) [1 3]
     (slice(None, None, None), 1) [2 4]
@@ -140,31 +170,27 @@ def slice_generator(data, axis=0):
         for j in range(data.shape[axis]):
             ij = (slice(None,None,None),)*axis + (j,)
             yield ij, data[(slice(None,None,None),)*axis + (j,)]
-    elif type(axis) in [type(()),type([])]:
-        data = np.asarray(data)
+        return
 
-        # the total number of iterations to be made
-        nmax = np.product(np.asarray(data.shape)[axis])
+    # the total number of iterations to be made
+    axis_lens = [data.shape[a] for a in axis]
+    nmax = seq_prod(axis_lens)
 
-        # calculate the 'divmod' paramter which is used to work out
-        # which index to use to use for each axis during iteration
-        mods = np.cumprod(np.asarray(data.shape)[axis])
-        divs = [1] + list(mods[:-1])
+    # calculate the 'divmod' parameter which is used to work out
+    # which index to use to use for each axis during iteration
+    mods = np.cumprod(axis_lens)
+    divs = [1] + list(mods[:-1])
 
-        # set up a full set of slices for the image, to be modified
-        # at each iteration
-        slices = [slice(0, s) for s in data.shape]
+    # set up a full set of slices for the image, to be modified
+    # at each iteration
+    slice_template = [slice(0, s) for s in data.shape]
 
-        n = 0
-        while True:
-
-            if n >= nmax:
-                raise StopIteration
-            for (a, div, mod) in zip(axis, divs, mods):
-                x = n / div % mod
-                slices[a] = x
-            n += 1
-            yield slices, data[slices]
+    for n in range(nmax):
+        slices = slice_template[:]
+        for (a, div, mod) in zip(axis, divs, mods):
+            x = int(n / div % mod)
+            slices[a] = x
+        yield slices, data[slices]
 
 
 def f_generator(f, iterable):
@@ -173,7 +199,7 @@ def f_generator(f, iterable):
     Examples
     --------
     >>> for i, d in f_generator(lambda x: x**2, data_generator([[1,2],[3,4]])):
-    ...     print i, d
+    ...     print(i, d)
     ...
     0 [1 4]
     1 [ 9 16]
@@ -190,7 +216,7 @@ def slice_parcels(data, labels=None, axis=0):
 
     >>> x=np.array([[0,0,0,1],[0,1,0,1],[2,2,0,1]])
     >>> for a in slice_parcels(x):
-    ...     print a, x[a]
+    ...     print(a, x[a])
     ...
     ((0,), array([ True,  True,  True, False], dtype=bool)) [0 0 0]
     ((0,), array([False, False, False,  True], dtype=bool)) [1]
@@ -201,7 +227,7 @@ def slice_parcels(data, labels=None, axis=0):
     ((2,), array([ True,  True, False, False], dtype=bool)) [2 2]
     >>> for a in slice_parcels(x, axis=1):
     ...     b, c = a
-    ...     print a, x[b][c]
+    ...     print(a, x[b][c])
     ...
     ((slice(None, None, None), 0), array([ True,  True, False], dtype=bool)) [0 0]
     ((slice(None, None, None), 0), array([False, False,  True], dtype=bool)) [2]
