@@ -4,12 +4,14 @@ docs.  In setup.py in particular, we exec this file, so it cannot import nipy
 """
 
 # nipy version information.  An empty _version_extra corresponds to a
-# full release.  '.dev' as a _version_extra string means this is a development
+# full release.  '.devN' as a _version_extra string means this is a development
 # version
+# See: https://www.python.org/dev/peps/pep-0440
 _version_major = 0
-_version_minor = 4
-_version_micro = 2
-# _version_extra = '.dev' # For development
+_version_minor = 5
+_version_micro = 0
+# _version_extra = '.dev2' # For development
+# _version_extra = 'rc1' # For release candidate
 _version_extra = '' # For release
 
 # Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
@@ -146,10 +148,10 @@ the nipy distribution.
 # Update in readme text above
 # Update in .travis.yml
 # Update in requirements.txt
-NUMPY_MIN_VERSION='1.6.0'
-SCIPY_MIN_VERSION = '0.9.0'
-NIBABEL_MIN_VERSION = '1.2'
-SYMPY_MIN_VERSION = '0.7.0'
+NUMPY_MIN_VERSION='1.14'
+SCIPY_MIN_VERSION = '1.0.0'
+NIBABEL_MIN_VERSION = '2.0'
+SYMPY_MIN_VERSION = '1.0'
 MAYAVI_MIN_VERSION = '3.0'
 CYTHON_MIN_VERSION = '0.12.1'
 
@@ -170,7 +172,7 @@ MINOR               = _version_minor
 MICRO               = _version_micro
 ISRELEASE           = _version_extra == ''
 VERSION             = __version__
-REQUIRES            = ["numpy", "scipy", "sympy", "nibabel"]
+REQUIRES            = ["numpy", "scipy", "sympy(<1.6)", "nibabel"]
 STATUS              = 'beta'
 
 # Versions and locations of optional data packages
