@@ -126,6 +126,7 @@ For saving a NIPY image to NIFTI, see the docstring for :func:`nipy2nifti`.
 For loading a NIFTI image to NIPY, see the docstring for :func:`nifti2nipy`.
 
 """
+from __future__ import absolute_import
 
 import sys
 
@@ -145,6 +146,8 @@ from ..core.reference import spaces as ncrs
 from ..core.image.image import Image
 from ..core.image.image_spaces import as_xyz_image
 
+from .nibcompat import get_header, get_affine
+
 
 XFORM2SPACE = {'scanner': ncrs.scanner_space,
                'aligned': ncrs.aligned_space,
@@ -336,12 +339,15 @@ def nipy2nifti(img, data_dtype=None, strict=None, fix0=True):
         elif not out_space in ncrs.unknown_space: # no space we recognize
             raise NiftiError('Image world not a NIFTI world')
         else: # unknown space requires affine that matches
+            # Set guessed shape to set zooms correctly
+            hdr.set_data_shape(img.shape)
+            # Use qform set to set the zooms, but with 'unknown' code
+            hdr.set_qform(xyz_affine, 'unknown')
+            hdr.set_sform(None)
             if not np.allclose(xyz_affine, hdr.get_base_affine()):
                 raise NiftiError("Image world is 'unknown' but affine not "
                                  "compatible; please reset image world or "
                                  "affine")
-            hdr.set_qform(None)
-            hdr.set_sform(None)
     # Use list() to get .index method for python < 2.6
     input_names = list(coordmap.function_domain.coord_names)
     spatial_names = input_names[:3]
@@ -385,7 +391,7 @@ def nipy2nifti(img, data_dtype=None, strict=None, fix0=True):
         # Make sure this time-like axis is first non-space axis
         if in_ax != 3:
             data = np.rollaxis(data, in_ax, 3)
-            order = range(n_ns)
+            order = list(range(n_ns))
             order.pop(in_ax - 3)
             order.insert(0, in_ax - 3)
             ns_pixdims = [ns_pixdims[i] for i in order]
@@ -432,7 +438,7 @@ def _find_time_like(coordmap, fix0):
                 same_time_out = non_space_onames.index(name) + 3
                 corr_in = out2in[same_time_out]
                 if corr_out is None:
-                    if not corr_in is None:
+                    if corr_in is not None:
                         raise NiftiError("Axis type '%s' found in input and "
                                          "output but they do not appear to "
                                          "match" % name)
@@ -530,8 +536,8 @@ def nifti2nipy(ni_img):
     Ignore the intent-related fields for now, but warn that we are doing so if
     there appears to be specific information in there.
     """
-    hdr = ni_img.get_header()
-    affine = ni_img.get_affine()
+    hdr = get_header(ni_img)
+    affine = get_affine(ni_img)
     # Affine will not be None from a loaded image, but just in case
     if affine is None:
         affine = hdr.get_best_affine()
@@ -558,11 +564,11 @@ def nifti2nipy(ni_img):
     # Get information from dim_info
     input_names3 = list('ijk')
     freq, phase, slice = hdr.get_dim_info()
-    if not freq is None:
+    if freq is not None:
         input_names3[freq] = 'freq'
-    if not phase is None:
+    if phase is not None:
         input_names3[phase] = 'phase'
-    if not slice is None:
+    if slice is not None:
         input_names3[slice] = 'slice'
     # Add to mm scaling, with warning
     space_units, time_like_units = hdr.get_xyzt_units()
