@@ -11,6 +11,7 @@ Author : Bertrand Thirion, 2009-2011
          Virgile Fritsch <virgile.fritsch@inria.fr>
 
 """
+from __future__ import absolute_import
 
 import numpy as np
 
@@ -349,12 +350,12 @@ class HierarchicalROI(SubDomains):
             c_pos = self.select_id(c_id)
             p_pos = self.parents[c_pos]
             p_id = self.get_id()[p_pos]
-            
+
             if p_pos != c_pos:
                 # this will be used in many places
                 mask_pos = np.ones(self.k, np.bool)
                 mask_pos[c_pos] = False
-                
+
                 # set new parents
                 self.parents = self.parents[mask_pos]
                 self.parents[self.parents == c_pos] = p_pos
@@ -365,7 +366,7 @@ class HierarchicalROI(SubDomains):
                 relabel[relabel == c_id] = p_id
 
                 # compute new features
-                for fid in self.features.keys():
+                for fid in list(self.features):
                     # replace feature
                     # (without the API since self is in an inconsistent state)
                     dj = self.get_feature(fid)
@@ -375,7 +376,7 @@ class HierarchicalROI(SubDomains):
                     self.features[fid] = dj
 
                 # compute new roi features
-                for fid in self.roi_features.keys():
+                for fid in list(self.roi_features):
                     dj = self.get_roi_feature(fid)
                     if fid in pull_features:
                         # modify only if `pull` requested
@@ -394,26 +395,26 @@ class HierarchicalROI(SubDomains):
         methods indicates the way possible features are dealt with
         (not implemented yet)
 
-        Caveat
-        ------
-        if roi_features have been defined, they will be removed
+        Notes
+        -----
+        Caveat: if roi_features have been defined, they will be removed
         """
         if pull_features is None:
             pull_features = []
 
         if self.k == 0:
             return
-        
+
         # relabel maps old labels to new labels 
         relabel = np.arange(self.k)
 
         # merge nodes, one at a time
         id_list = self.get_id()[:: - 1]
-        
+
         for p_id in id_list:
             p_pos = self.select_id(p_id)
             p_children = np.nonzero(self.parents == p_pos)[0]
-            
+
             if p_pos in p_children:
                 # remove current node from its children list
                 p_children = p_children[p_children != p_pos]
@@ -434,9 +435,9 @@ class HierarchicalROI(SubDomains):
                 # merge labels
                 relabel[relabel == p_pos] = relabel[c_pos]
                 self.k -= 1
-                
+
                 # compute new features
-                for fid in self.features.keys():
+                for fid in list(self.features):
                     # replace feature
                     # (without the API since self is in an inconsistent state)
                     dj = self.get_feature(fid)
@@ -446,13 +447,13 @@ class HierarchicalROI(SubDomains):
                     self.features[fid] = dj
 
                 # compute new roi features
-                for fid in self.roi_features.keys():
+                for fid in list(self.roi_features):
                     dj = self.get_roi_feature(fid)
                     if fid in pull_features:
                         # modify only if `pull` requested
                         dj[c_pos] = dj[p_pos]
                     self.roi_features[fid] = dj[mask_pos]
-                                        
+
         # update HROI structure
         self.label[self.label > -1] = relabel[self.label[self.label > - 1]]
         self.recompute_labels()
@@ -507,10 +508,10 @@ class HierarchicalROI(SubDomains):
         cp = HierarchicalROI(
             self.domain, self.label.copy(), self.parents.copy(), self.get_id())
         # copy features
-        for fid in self.features.keys():
+        for fid in self.features:
             cp.set_feature(fid, self.get_feature(fid))
         # copy ROI features
-        for fid in self.roi_features.keys():
+        for fid in self.roi_features:
             cp.set_roi_feature(fid, self.get_roi_feature(fid))
         return cp
 
@@ -597,9 +598,9 @@ def make_hroi_from_subdomain(sub_domain, parents):
     """
     hroi = HierarchicalROI(sub_domain.domain, sub_domain.label, parents)
     # set features
-    for fid in sub_domain.features.keys():
+    for fid in sub_domain.features:
         hroi.set_feature(fid, sub_domain.get_feature(fid))
     # set ROI features
-    for fid in sub_domain.roi_features.keys():
+    for fid in sub_domain.roi_features:
         hroi.set_roi_feature(fid, sub_domain.get_roi_feature(fid))
     return hroi
