@@ -10,6 +10,7 @@ In those tests, we often access some ROI directly by a fixed index
 instead of using the utility functions such as get_id() or select_id().
 
 """
+from __future__ import absolute_import
 
 import numpy as np
 from numpy.testing import assert_equal
@@ -67,7 +68,7 @@ def test_hroi_isleaf():
     """ Test basic construction of a tree of isolated leaves
     """
     hroi = make_hroi()
-    hroi.select_roi([0] + range(2, 9))
+    hroi.select_roi([0] + list(range(2, 9)))
     assert_equal(hroi.k, 8)
 
 
@@ -76,7 +77,7 @@ def test_hroi_isleaf_2():
     """
     hroi = make_hroi()
     #import pdb; pdb.set_trace()
-    hroi.select_roi(range(1, 9))
+    hroi.select_roi(list(range(1, 9)))
     assert_equal(hroi.parents, np.arange(8).astype(np.int))
 
 
@@ -86,7 +87,6 @@ def test_asc_merge():
     hroi = make_hroi()
     s1 = hroi.get_size(0) + hroi.get_size(1)
     total_size = np.sum([hroi.get_size(id) for id in hroi.get_id()])
-    #import pdb; pdb.set_trace()
     assert_equal(hroi.get_size(0, ignore_children=False), total_size)
     hroi.merge_ascending([1])
     assert_equal(hroi.get_size(0), s1)
@@ -96,7 +96,6 @@ def test_asc_merge_2():
     """ Test ascending merge
 
     Test that ROI being their own parent are inchanged.
-
     """
     hroi = make_hroi()
     s1 = hroi.get_size(0)
@@ -121,8 +120,8 @@ def test_asc_merge_4():
 
     """
     hroi = make_hroi()
-    hroi.set_roi_feature('labels', range(9))
-    hroi.set_roi_feature('labels2', range(9))
+    hroi.set_roi_feature('labels', list(range(9)))
+    hroi.set_roi_feature('labels2', list(range(9)))
     parents = np.arange(9) - 1
     parents[0] = 0
     hroi.parents = parents
