@@ -4,6 +4,7 @@
 3D visualization of activation maps using Mayavi
 
 """
+from __future__ import absolute_import
 
 # Author: Gael Varoquaux <gael dot varoquaux at normalesup dot org>
 # License: BSD
@@ -56,13 +57,13 @@ def affine_img_src(data, affine, scale=1, name='AffineImage',
         # Try out old install of Mayavi, with namespace packages
         from enthought.mayavi.sources.api import ArraySource
     center = np.r_[0, 0, 0, 1]
-    spacing = np.diag(affine)[:3]
+    spacing = np.diag(affine)[:3].copy()
     origin = np.dot(affine, center)[:3]
     if reverse_x:
         # Radiologic convention
         spacing[0] *= -1
         origin[0] *= -1
-    src = ArraySource(scalar_data=np.asarray(data, dtype=np.float), 
+    src = ArraySource(scalar_data=np.asarray(data, dtype=np.float),
                            name=name,
                            spacing=scale*spacing,
                            origin=scale*origin)
@@ -137,7 +138,20 @@ def m2screenshot(mayavi_fig=None, mpl_axes=None, autocrop=True):
 def plot_anat_3d(anat=None, anat_affine=None, scale=1,
                  sulci_opacity=0.5, gyri_opacity=0.3,
                  opacity=None,
+                 skull_percentile=78, wm_percentile=79,
                  outline_color=None):
+    """ 3D anatomical display
+
+    Parameters
+    ----------
+    skull_percentile : float, optional
+        The percentile of the values in the image that delimit the skull from
+        the outside of the brain. The smaller the fraction of you field of view
+        is occupied by the brain, the larger this value should be.
+    wm_percentile : float, optional
+        The percentile of the values in the image that delimit the white matter
+        from the grey matter. Typical this is skull_percentile + 1
+    """
     # Late import to avoid triggering wx imports before needed.
     try:
         from mayavi import mlab
@@ -150,16 +164,26 @@ def plot_anat_3d(anat=None, anat_affine=None, scale=1,
     if anat is None:
         anat, anat_affine, anat_max = _AnatCache.get_anat()
         anat_blurred = _AnatCache.get_blurred()
+        skull_threshold = 4800
+        inner_threshold = 5000
+        upper_threshold = 7227.8
     else:
         from scipy import ndimage
         # XXX: This should be in a separate function
+        voxel_size = np.sqrt((anat_affine[:3, :3]**2).sum()/3.)
+        skull_threshold = stats.scoreatpercentile(anat.ravel(), 
+                skull_percentile)
+        inner_threshold = stats.scoreatpercentile(anat.ravel(), 
+                wm_percentile)
+        upper_threshold = anat.max()
         anat_blurred = ndimage.gaussian_filter(
-                                        (ndimage.morphology.binary_fill_holes(
-                                            ndimage.gaussian_filter(
-                                                    (anat > 4800).astype(np.float), 6)
-                                                > 0.5
-                                            )).astype(np.float),
-                                        2).T.ravel()
+                            (ndimage.morphology.binary_fill_holes(
+                                ndimage.gaussian_filter(
+                                    (anat > skull_threshold).astype(np.float), 
+                                    6./voxel_size)
+                                    > 0.5
+                                )).astype(np.float),
+                            2./voxel_size).T.ravel()
 
     if opacity is None:
         try:
@@ -194,11 +218,12 @@ def plot_anat_3d(anat=None, anat_affine=None, scale=1,
     cortex = mlab.pipeline.surface(cortex_surf,
                 colormap='copper', 
                 opacity=opacity,
-                vmin=4800, vmax=5000)
+                vmin=skull_threshold, 
+                vmax=inner_threshold)
     cortex.enable_contours = True
     cortex.contour.filled_contours = True
     cortex.contour.auto_contours = False
-    cortex.contour.contours = [0, 5000, 7227.8]
+    cortex.contour.contours = [0, inner_threshold, upper_threshold]
     #cortex.actor.property.backface_culling = True
     # XXX: Why do we do 'frontface_culling' to see the front.
     cortex.actor.property.frontface_culling = True
@@ -246,7 +271,7 @@ def plot_map_3d(map, affine, cut_coords=None, anat=None, anat_affine=None,
             The MNI coordinates of a 3D cursor to indicate a feature
             or a cut, in MNI coordinates and order.
         anat : 3D ndarray, optional
-            The anatomical image to be used as a background. If None, the 
+            The anatomical image to be used as a background. If None, the
             MNI152 T1 1mm template is used. If False, no anatomical
             image is used.
         anat_affine : 4x4 ndarray, optional
@@ -265,7 +290,7 @@ def plot_map_3d(map, affine, cut_coords=None, anat=None, anat_affine=None,
         vmax : float, optional
             The maximum value, for the colormap
         cmap : a callable, or a pylab colormap
-            A callable returning a (n, 4) array for n values between 
+            A callable returning a (n, 4) array for n values between
             0 and 1 for the colors. This can be for instance a pylab
             colormap.
 
@@ -273,7 +298,7 @@ def plot_map_3d(map, affine, cut_coords=None, anat=None, anat_affine=None,
         -----
 
         If you are using a VTK version below 5.2, there is no way to
-        avoid opening a window during the rendering under Linux. This is 
+        avoid opening a window during the rendering under Linux. This is
         necessary to use the graphics card for the rendering. You must
         maintain this window on top of others and on the screen.
 
@@ -324,18 +349,18 @@ def plot_map_3d(map, affine, cut_coords=None, anat=None, anat_affine=None,
         module = mlab.pipeline.iso_surface(map_src,
                                         contours=contours,
                                         vmin=vmin, vmax=vmax)
-        if callable(cmap):
+        if hasattr(cmap, '__call__'):
             # Stick the colormap in mayavi
             module.module_manager.scalar_lut_manager.lut.table \
                     = (255*cmap(np.linspace(0, 1, 256))).astype(np.int)
     else:
         module = None
-   
+
     if not anat is False:
         plot_anat_3d(anat=anat, anat_affine=anat_affine, scale=1.05,
                      outline_color=(.9, .9, .9),
                      gyri_opacity=.2)
-   
+
     ###########################################################################
     # Draw the cursor
     if cut_coords is not None:
@@ -346,7 +371,7 @@ def plot_map_3d(map, affine, cut_coords=None, anat=None, anat_affine=None,
                     color=(.5, .5, .5), tube_radius=0.25)
         mlab.plot3d((x0, x0), (y0, y0), (-72, 109), 
                             color=(.5, .5, .5), tube_radius=0.25)
-    
+
     mlab.view(*view)
     fig.scene.disable_render = disable_render
     
