@@ -6,10 +6,12 @@ The Slicer classes.
 The main purpose of these classes is to have auto adjust of axes size to
 the data with different layout of cuts.
 """
-
-import operator
+from __future__ import absolute_import
 
 import numpy as np
+
+from nipy.utils import is_iterable
+
 from nipy.utils.skip_test import skip_if_running_nose
 
 try:
@@ -267,7 +269,7 @@ class BaseSlicer(object):
             axes = [0., 0., 1., 1.]
             if leave_space:
                 axes = [0.3, 0, .7, 1.]
-        if operator.isSequenceType(axes):
+        if is_iterable(axes):
             axes = figure.add_axes(axes)
         # People forget to turn their axis off, or to set the zorder, and
         # then they cannot see their slicer
@@ -374,11 +376,17 @@ class BaseSlicer(object):
                             get_mask_bounds(not_mask, affine)
             if kwargs.get('vmin') is None and kwargs.get('vmax') is None:
                 # Avoid dealing with masked arrays: they are slow
-                masked_map = np.asarray(map)[not_mask]
+                if not np.any(not_mask):
+                    # Everything is masked
+                    vmin = vmax = 0
+                else:
+                    masked_map = np.asarray(map)[not_mask]
+                    vmin = masked_map.min()
+                    vmax = masked_map.max()
                 if kwargs.get('vmin') is None:
-                    kwargs['vmin'] = masked_map.min()
+                    kwargs['vmin'] = vmin
                 if kwargs.get('max') is None:
-                    kwargs['vmax'] = masked_map.max()
+                    kwargs['vmax'] = vmax
         else:
             if not 'vmin' in kwargs:
                 kwargs['vmin'] = map.min()
@@ -388,7 +396,7 @@ class BaseSlicer(object):
         bounding_box = (xmin_, xmax_), (ymin_, ymax_), (zmin_, zmax_)
 
         # For each ax, cut the data and plot it
-        for cut_ax in self.axes.itervalues():
+        for cut_ax in self.axes.values():
             try:
                 cut = cut_ax.do_cut(map, affine)
             except IndexError:
@@ -417,7 +425,7 @@ class BaseSlicer(object):
         data_bounds = get_bounds(map.shape, affine)
 
         # For each ax, cut the data and plot it
-        for cut_ax in self.axes.itervalues():
+        for cut_ax in self.axes.values():
             try:
                 cut = cut_ax.do_cut(map, affine)
                 edge_mask = _edge_map(cut)
@@ -521,7 +529,7 @@ class OrthoSlicer(BaseSlicer):
         x_ax = cut_ax_dict['x']
         y_ax = cut_ax_dict['y']
         z_ax = cut_ax_dict['z']
-        for cut_ax in cut_ax_dict.itervalues():
+        for cut_ax in cut_ax_dict.values():
             bounds = cut_ax.get_object_bounds()
             if not bounds:
                 # This happens if the call to _map_show was not
@@ -532,7 +540,7 @@ class OrthoSlicer(BaseSlicer):
             xmin, xmax, ymin, ymax = bounds
             width_dict[cut_ax.ax] = (xmax - xmin)
         total_width = float(sum(width_dict.values()))
-        for ax, width in width_dict.iteritems():
+        for ax, width in width_dict.items():
             width_dict[ax] = width/total_width*(x1 -x0)
         left_dict = dict()
         left_dict[y_ax.ax] = x0
@@ -582,7 +590,7 @@ def demo_ortho_slicer():
     """
     pl.clf()
     oslicer = OrthoSlicer(cut_coords=(0, 0, 0))
-    from anat_cache import _AnatCache
+    from .anat_cache import _AnatCache
     map, affine, _ = _AnatCache.get_anat()
     oslicer.plot_map(map, affine, cmap=pl.cm.gray)
     return oslicer
@@ -659,7 +667,7 @@ class BaseStackedSlicer(BaseSlicer):
         x0, y0, x1, y1 = self.rect
         width_dict = dict()
         cut_ax_dict = self.axes
-        for cut_ax in cut_ax_dict.itervalues():
+        for cut_ax in cut_ax_dict.values():
             bounds = cut_ax.get_object_bounds()
             if not bounds:
                 # This happens if the call to _map_show was not
@@ -670,7 +678,7 @@ class BaseStackedSlicer(BaseSlicer):
             xmin, xmax, ymin, ymax = bounds
             width_dict[cut_ax.ax] = (xmax - xmin)
         total_width = float(sum(width_dict.values()))
-        for ax, width in width_dict.iteritems():
+        for ax, width in width_dict.items():
             width_dict[ax] = width/total_width*(x1 -x0)
         left_dict = dict()
         left = float(x0)
