@@ -1,6 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import with_statement
 """
 This module implements an object to deal with experimental paradigms.
 In fMRI data analysis, there are two main types of experimental
@@ -18,10 +17,12 @@ yielding a paradigm is in fact a session index
 
 Author: Bertrand Thirion, 2009-2011
 """
+from __future__ import absolute_import
 
 import numpy as np
 
 from ...utils.compat3 import open4csv
+import warnings
 
 ##########################################################
 # Paradigm handling
@@ -46,17 +47,9 @@ class Paradigm(object):
         self.con_id = con_id
         self.onset = onset
         self.amplitude = amplitude
-        self.n_event = 0
         if con_id is not None:
             self.n_events = len(con_id)
-            try:
-                # this is only for backward compatibility:
-                #if con_id were integers, they become a string
-                self.con_id = np.array(['c' + str(int(float(c)))
-                                        for c in con_id])
-            except:
-                self.con_id = np.ravel(np.array(con_id)).astype('str')
-
+            self.con_id = np.ravel(np.array(con_id)).astype('str')
         if onset is not None:
             if len(onset) != self.n_events:
                 raise ValueError(
@@ -165,13 +158,13 @@ def load_paradigm_from_csv_file(path, session=None):
 
     Notes
     -----
-    It is assumed that the csv file contains the following columns: (session id,
-    condition id, onset), plus possibly (duration) and/or (amplitude). If all
-    the durations are 0, the paradigm will be handled as event-related.
+    It is assumed that the csv file contains the following columns:
+    (session id, condition id, onset),
+    plus possibly (duration) and/or (amplitude).
+    If all the durations are 0, the paradigm will be handled as event-related.
 
-    Fixme
-    -----
-    would be much clearer if amplitude was put before duration in the .csv
+    FIXME: would be much clearer if amplitude was put before duration in the
+    .csv
     """
     import csv
     with open4csv(path, 'r') as csvfile:
