@@ -1,3 +1,6 @@
+from __future__ import absolute_import
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 
 __docformat__ = 'restructuredtext'
 
@@ -30,7 +33,8 @@ def invertR(delta, IRF, niter=20):
 
     c = delta.max() / (np.pi/2)
     n = delta.shape[0]
-    delta0 = (delta[n/2+2] - delta[n/2+1])/(R[n/2+2] - R[n/2+1])
+    delta0 = ((delta[n // 2 + 2] - delta[n // 2 + 1])
+              / (R[n // 2 + 2] - R[n // 2 + 1]))
     if delta0 < 0:
         c = (delta.max() / (np.pi/2)) * 1.2
     else:
@@ -45,7 +49,7 @@ def invertR(delta, IRF, niter=20):
                      niter=niter)
 
     for iteration in model:
-        model.next()
+        next(model)
 
     a, b, c = model.theta
 
@@ -53,7 +57,7 @@ def invertR(delta, IRF, niter=20):
         return a * np.arctan(b * r) + c
 
     def _ddeltahat(r):
-        return a * b / (1 + (b * r)**2) 
+        return a * b / (1 + (b * r)**2)
 
     def _deltahatinv(d):
         return np.tan((d - c) / a) / b
