@@ -15,13 +15,14 @@ gets a bit more complicated when taking arbitrary shaped samples from the image,
 as we do for estimating the AR coefficients, where we take all the voxels with
 similar AR coefficients at once.
 """
+from __future__ import absolute_import
 
 import copy
 
 import os.path as path
 
 import numpy as np
-import scipy.linalg as spl
+import numpy.linalg as npl
 
 from nipy.algorithms.statistics.models.regression import (
     OLSModel, ARModel, ar_bias_corrector, ar_bias_correct)
@@ -127,10 +128,13 @@ class OLS(object):
     volume_start_times :
     """
 
-    def __init__(self, fmri_image, formula, outputs=[], 
+    def __init__(self, fmri_image, formula, outputs=[],
                  volume_start_times=None):
         self.fmri_image = fmri_image
-        self.data = np.asarray(fmri_image)
+        try:
+            self.data = fmri_image.get_data()
+        except AttributeError:
+            self.data = fmri_image.get_list_data(axis=0)
         self.formula = formula
         self.outputs = outputs
         if volume_start_times is None:
@@ -176,7 +180,7 @@ def estimateAR(resid, design, order=1):
     output : array
         shape (order, resid
     """
-    invM = ar_bias_corrector(design, spl.pinv(design), order)
+    invM = ar_bias_corrector(design, npl.pinv(design), order)
     return ar_bias_correct(resid, order, invM)
 
 
@@ -193,7 +197,7 @@ class AR1(object):
     formula :  :class:`nipy.algorithms.statistics.formula.Formula`
     rho : ``Image``
        image of AR(1) coefficients.  Returning data from
-       ``np.asarray(rho)``, and having attribute ``coordmap``
+       ``rho.get_data()``, and having attribute ``coordmap``
     outputs :
     volume_start_times : 
     """
@@ -201,12 +205,15 @@ class AR1(object):
     def __init__(self, fmri_image, formula, rho, outputs=[],
                  volume_start_times=None):
         self.fmri_image = fmri_image
-        self.data = np.asarray(fmri_image)
+        try:
+            self.data = fmri_image.get_data()
+        except AttributeError:
+            self.data = fmri_image.get_list_data(axis=0)
         self.formula = formula
         self.outputs = outputs
         # Cleanup rho values, truncate them to a scale of 0.01
         g = copy.copy(rho.coordmap)
-        rho = np.asarray(rho)
+        rho = rho.get_data()
         m = np.isnan(rho)
         r = (np.clip(rho,-1,1) * 100).astype(np.int) / 100.
         r[m] = np.inf
@@ -220,7 +227,7 @@ class AR1(object):
 
         iterable = parcels(self.rho, exclude=[np.inf])
         def model_params(i):
-            return (np.asarray(self.rho)[i].mean(),)
+            return (self.rho.get_data()[i].mean(),)
         # Generates indexer, data, model
         m = model_generator(self.formula, self.data,
                             self.volume_start_times,
@@ -402,16 +409,15 @@ def output_resid(outfile, fmri_image, clobber=False):
         T[0,0] = (fmri_image.volume_start_times[1:] -
                   fmri_image.volume_start_times[:-1]).mean()
         # FIXME: NIFTI specific naming here
-        innames = ["l"] + list(g.function_range.coord_names)
-        outnames = ["t"] + list(g.function_domain.coord_names)
-        cmap = AffineTransform.from_params(innames,
-                                  outnames, T)
+        innames = ["t"] + list(g.function_domain.coord_names)
+        outnames = ["t"] + list(g.function_range.coord_names)
+        cmap = AffineTransform.from_params(innames, outnames, T)
         shape = (n,) + fmri_image[0].shape
     elif isinstance(fmri_image, Image):
         cmap = fmri_image.coordmap
         shape = fmri_image.shape
     else:
-        raise ValueError, "expecting FmriImageList or 4d Image"
+        raise ValueError("expecting FmriImageList or 4d Image")
 
     outim = ModelOutputImage(outfile, cmap, shape, clobber=clobber)
     return outputters.RegressionOutput(outim, outputters.output_resid)
